use super::File;
use std::path::PathBuf;
use byteorder::{ByteOrder, BigEndian, LittleEndian};
use tool_helper::{Error, format_if_error, read_file};

#[repr(packed)]
struct OverlayHeader {
    pub start_adr: u32,
    pub _lba_count: u16,
}

impl OverlayHeader {
    pub fn lba_count_offset() -> usize {
        let dummy = OverlayHeader{start_adr: 0, _lba_count: 0}.start_adr;
        std::mem::size_of_val(&dummy)
    }
}

pub fn load_from(file_path: PathBuf) -> Result<File, Error> {
    let content = read_file(&file_path)?;

    if content.len() < std::mem::size_of::<OverlayHeader>() {
        return Err(Error::from_text(format!("Overlay {} has no header!", file_path.to_string_lossy())));
    }

    let lba_count = LittleEndian::read_u16(&content[OverlayHeader::lba_count_offset()..]);
    println!("Dino: {}", lba_count);

    Err(Error::not_implemented("load_from overlay"))
}